@@ -67,6 +67,16 @@ fn develop_pyo3_mixed_submodule() {
     ));
 }
 
+#[test]
+fn develop_pyo3_mixed_implicit() {
+    handle_result(develop::test_develop(
+        "test-crates/pyo3-mixed-implicit",
+        None,
+        "develop-pyo3-mixed-implicit",
+        false,
+    ));
+}
+
 #[test]
 fn develop_pyo3_mixed_py_subdir() {
     handle_result(develop::test_develop(
@@ -216,6 +226,17 @@ fn integration_pyo3_mixed_submodule() {
     ));
 }
 
+#[test]
+fn integration_pyo3_mixed_implicit() {
+    handle_result(integration::test_integration(
+        "test-crates/pyo3-mixed-implicit",
+        None,
+        "integration-pyo3-mixed-implicit",
+        false,
+        None,
+    ));
+}
+
 #[test]
 fn integration_pyo3_mixed_py_subdir() {
     handle_result(integration::test_integration(
@@ -332,7 +353,7 @@ fn integration_with_data() {
 }
 
 #[test]
-// Sourced from https://pypi.org/project/wasmtime/7.0.0/#files
+// Sourced from https://pypi.org/project/wasmtime/11.0.0/#files
 // update with wasmtime updates
 #[cfg(any(
     all(target_os = "windows", target_arch = "x86_64"),
